@@ -12,7 +12,7 @@ class Alignment(object):
 
     interface.implements(IService, IActionProvider)
 
-    gui_manager = inject('gui_manager')
+    component_registry = inject('component_registry')
 
     menu_xml = """
       <ui>
@@ -37,11 +37,10 @@ class Alignment(object):
         self._last_update = None
 
     def init(self, app):
-	self._app = app
-        app.register_handler(self.update)
+        self.component_registry.register_handler(self.update)
     
     def shutdown(self):
-        self._app.unregister_handler(self.update)
+        self.component_registry.unregister_handler(self.update)
 
     @component.adapter(IDiagramSelectionChange)
     def update(self, event=None):
