@@ -11,7 +11,7 @@ import stock
 
 from zope import component
 
-from gaphor.application import Application
+from gaphor.core import inject
 from gaphor import UML
 from gaphor.UML.event import ElementCreateEvent, ModelFactoryEvent, FlushFactoryEvent, DerivedSetEvent
 from gaphor.UML.interfaces import IAttributeChangeEvent, IElementDeleteEvent
@@ -49,7 +49,7 @@ def catchall(func):
         try:
             func(*args, **kwargs)
         except Exception, e:
-            log.error('Exception in %s. Try to refresh the entire model' % (func,), e)
+            log.error('Exception in %s. Try to refresh the entire model' % (func,), exc_info=True)
             try:
                 args[0].refresh()
             except Exception, e:
@@ -69,13 +69,14 @@ class NamespaceModel(gtk.GenericTreeModel):
     
     """
 
+    component_registry = inject('component_registry')
 
     def __init__(self, factory):
         # Init parent:
         gtk.GenericTreeModel.__init__(self)
 
         # We own the references to the iterators.
-        self.set_property ('leak_references', 0)
+        self.set_property ('leak-references', 0)
 
         self.factory = factory
 
@@ -83,12 +84,13 @@ class NamespaceModel(gtk.GenericTreeModel):
 
         self.filter = _default_filter_list
 
-        Application.register_handler(self.flush)
-        Application.register_handler(self.refresh)
-        Application.register_handler(self._on_element_change)
-        Application.register_handler(self._on_element_create)
-        Application.register_handler(self._on_element_delete)
-        Application.register_handler(self._on_association_set)
+        cr = self.component_registry
+        cr.register_handler(self.flush)
+        cr.register_handler(self.refresh)
+        cr.register_handler(self._on_element_change)
+        cr.register_handler(self._on_element_create)
+        cr.register_handler(self._on_element_delete)
+        cr.register_handler(self._on_association_set)
 
         self._build_model()
 
@@ -97,12 +99,13 @@ class NamespaceModel(gtk.GenericTreeModel):
         """
         Close the namespace model, unregister handlers.
         """
-        Application.unregister_handler(self.flush)
-        Application.unregister_handler(self.refresh)
-        Application.unregister_handler(self._on_element_change)
-        Application.unregister_handler(self._on_element_create)
-        Application.unregister_handler(self._on_element_delete)
-        Application.unregister_handler(self._on_association_set)
+        cr = self.component_registry
+        cr.unregister_handler(self.flush)
+        cr.unregister_handler(self.refresh)
+        cr.unregister_handler(self._on_element_change)
+        cr.unregister_handler(self._on_element_create)
+        cr.unregister_handler(self._on_element_delete)
+        cr.unregister_handler(self._on_association_set)
 
 
     def path_from_element(self, e):
@@ -178,9 +181,7 @@ class NamespaceModel(gtk.GenericTreeModel):
         """
         if type(element) not in self.filter:
             return
-        if type(element) is UML.Property and element.namespace is None:
-            return
-        if element.namespace and type(element.namespace) not in self.filter:
+        if element.namespace not in self._nodes:
             return
 
         self._nodes.setdefault(element, [])
@@ -226,12 +227,15 @@ class NamespaceModel(gtk.GenericTreeModel):
     @catchall
     def _on_element_delete(self, event):
         element = event.element
-        if type(element) is UML.Property and element.namespace is None:
-            return
+
+        #log.debug('Namespace received deleting element %s' % element)
+
         if event.service is self.factory and \
                 type(element) in self.filter:
             path = self.path_from_element(element)
 
+            #log.debug('Deleting element %s from path %s' % (element, path))
+
             # Remove all sub-elements:
             if path:
                 self.row_deleted(path)
@@ -277,6 +281,7 @@ class NamespaceModel(gtk.GenericTreeModel):
 
             # Add to new place. This may fail if the type of the new place is
             # not in the tree model (because it's filtered)
+            log.debug('Trying to add %s to %s' % (element, new_value))
             if self._nodes.has_key(new_value):
                 if self._nodes.has_key(element):
                     parent = self._nodes[new_value]
@@ -415,6 +420,17 @@ class NamespaceModel(gtk.GenericTreeModel):
         return node.namespace
 
 
+    # TreeDragDest
+
+    def row_drop_possible(self, dest_path, selection_data):
+        print 'row_drop_possible', dest_path, selection_data
+        return True
+
+
+    def drag_data_received(self, dest, selection_data):
+        print 'drag_data_received', dest_path, selection_data
+
+
 class NamespaceView(gtk.TreeView):
 
     TARGET_STRING = 0
@@ -423,11 +439,6 @@ class NamespaceView(gtk.TreeView):
         ('STRING', 0, TARGET_STRING),
         ('text/plain', 0, TARGET_STRING),
         ('gaphor/element-id', 0, TARGET_ELEMENT_ID)]
-    # Can not set signals for some reason...
-    #__gsignals__ = { 'drag-drop': 'override',
-    #                 'drag-data-get': 'override',
-    #                 'drag-data-delete': 'override',
-    #                 'drag-data-received': 'override' }
 
     def __init__(self, model, factory):
         assert isinstance (model, NamespaceModel), 'model is not a NamespaceModel (%s)' % str(model)
@@ -464,24 +475,20 @@ class NamespaceView(gtk.TreeView):
         assert len (column.get_cell_renderers()) == 2
         self.append_column (column)
 
-        # DND info:
         # drag
-        self.enable_model_drag_source(gtk.gdk.BUTTON1_MASK,
-                             [NamespaceView.DND_TARGETS[-1]],
-                             gtk.gdk.ACTION_DEFAULT | gtk.gdk.ACTION_MOVE)
         self.drag_source_set(gtk.gdk.BUTTON1_MASK | gtk.gdk.BUTTON3_MASK,
                              NamespaceView.DND_TARGETS,
-                             gtk.gdk.ACTION_COPY | gtk.gdk.ACTION_LINK)
+                             gtk.gdk.ACTION_COPY | gtk.gdk.ACTION_MOVE)
+        self.connect('drag-begin', NamespaceView.on_drag_begin)
         self.connect('drag-data-get', NamespaceView.on_drag_data_get)
+        self.connect('drag-data-delete', NamespaceView.on_drag_data_delete)
 
         # drop
-        #self.drag_dest_set (gtk.DEST_DEFAULT_ALL, [NamespaceView.DND_TARGETS[-1]],
-        #                    gtk.gdk.ACTION_DEFAULT)
-        self.enable_model_drag_dest([NamespaceView.DND_TARGETS[-1]],
-                                    gtk.gdk.ACTION_DEFAULT)
-        self.connect('drag-data-received', NamespaceView.on_drag_data_received)
+        self.drag_dest_set (gtk.DEST_DEFAULT_ALL, [NamespaceView.DND_TARGETS[-1]],
+                            gtk.gdk.ACTION_MOVE)
+        self.connect('drag-motion', NamespaceView.on_drag_motion)
         self.connect('drag-drop', NamespaceView.on_drag_drop)
-        self.connect('drag-data-delete', NamespaceView.on_drag_data_delete)
+        self.connect('drag-data-received', NamespaceView.on_drag_data_received)
 
 
     def get_selected_element(self):
@@ -549,8 +556,8 @@ class NamespaceView(gtk.TreeView):
             log.error('Could not create path from string "%s"' % path_str)
 
 
-#    def do_drag_begin (self, context):
-#        print 'do_drag_begin'
+    def on_drag_begin(self, context):
+        return True
 
 
     def on_drag_data_get(self, context, selection_data, info, time):
@@ -558,7 +565,6 @@ class NamespaceView(gtk.TreeView):
         Get the data to be dropped by on_drag_data_received().
         We send the id of the dragged element.
         """
-        #log.debug('on_drag_data_get')
         selection = self.get_selection()
         model, iter = selection.get_selected()
         if iter:
@@ -570,26 +576,54 @@ class NamespaceView(gtk.TreeView):
                 selection_data.set(selection_data.target, 8, '%s#%s' % (element.id, p))
             else:
                 selection_data.set(selection_data.target, 8, '%s#%s' % (element.name, p))
+        return True
 
 
     def on_drag_data_delete (self, context):
         """
-        DnD magic. do not touch.
+        Delete data from original site, when `ACTION_MOVE` is used.
         """
         self.emit_stop_by_name('drag-data-delete')
 
 
     # Drop
+    def on_drag_motion(self, context, x, y, time):
+        try:
+            path, pos = self.get_dest_row_at_pos(x, y)
+            self.set_drag_dest_row(path, pos)
+        except TypeError:
+            self.set_drag_dest_row(len(self.get_model()) - 1, gtk.TREE_VIEW_DROP_AFTER)
+
+        kind = gtk.gdk.ACTION_COPY
+
+        context.drag_status(kind, time)
+        return True
+
+    def on_drag_drop(self, context, x, y, time):
+        """
+        Determine if drop is allowed.
+        """
+        if 'gaphor/element-id' in context.targets:
+            self.emit_stop_by_name('drag-drop')
+            self.drag_get_data(context, context.targets[-1], time)
+            return True
+        return False
+
+
     def on_drag_data_received(self, context, x, y, selection, info, time):
         """
         Drop the data send by on_drag_data_get().
         """
+        #print 'data-received', NamespaceView.TARGET_ELEMENT_ID, 'in', context.targets
         self.emit_stop_by_name('drag-data-received')
-        #print 'drag_data_received'
-        n, p = selection.data.split('#')
-        drop_info = self.get_dest_row_at_pos(x, y)
+        if 'gaphor/element-id' in context.targets:
+            #print 'drag_data_received'
+            n, p = selection.data.split('#')
+            drop_info = self.get_dest_row_at_pos(x, y)
+        else:
+            drop_info = None
+
         if drop_info:
-            #print 'drop_info', drop_info
             model = self.get_model()
             element = self.factory.lookup(n)
             path, position = drop_info
@@ -622,7 +656,8 @@ class NamespaceView(gtk.TreeView):
                     element.package = dest_element
                 tx.commit()
 
-            except AttributeError:
+            except AttributeError, e:
+                #log.info('Unable to drop data', e)
                 context.drop_finish(False, time)
             else:
                 context.drop_finish(True, time)
@@ -634,17 +669,4 @@ class NamespaceView(gtk.TreeView):
                 selection.select_path(path)
 
 
-    def on_drag_drop(self, context, x, y, time):
-        """
-        DnD magic. do not touch
-        """
-        self.emit_stop_by_name('drag-drop')
-        self.drag_get_data(context, context.targets[-1], time)
-        return 1
-
-
-gobject.type_register(NamespaceModel)
-gobject.type_register(NamespaceView)
-
-
 # vim: sw=4:et:ai
